@@ -102,6 +102,27 @@ class CfPostgresql(CfDatabase):
         else:
             return True
 
+    def schema_exists(self, schema_name: str = None) -> bool:
+        """Test for the existence of a schema.
+
+        Args:
+            schema_name: Name of the schema to search for.
+        Returns:
+            True, if schema exists. False, if not.
+        """
+        results = self.execute(f'''
+                    SELECT EXISTS(
+                      SELECT 1
+                      FROM information_schema.schemata
+                      WHERE schema_name = '{schema_name}'
+                    );
+                ''')
+
+        if results[0][0] is not True:
+            return False
+        else:
+            return True
+
     def table_exists(self, table_path: str = None) -> bool:
         """Test for the existence of a schema table.
 
